@@ -7,6 +7,12 @@
 //!   - Optional, enabled by default
 //!   - Requires Rust 1.6 *to disable*
 //!   - Use libstd
+//!
+//! - `use_union`
+//!   - Optional
+//!   - Requires Rust nightly channel
+//!   - Use the unstable feature untagged unions for the internal implementation,
+//!     which has reduced space overhead
 #![cfg_attr(not(feature="std"), no_std)]
 extern crate odds;
 extern crate nodrop;
@@ -125,6 +131,18 @@ impl<A: Array> ArrayVec<A> {
     #[inline]
     pub fn capacity(&self) -> usize { A::capacity() }
 
+    /// Return if the `ArrayVec` is completely filled.
+    ///
+    /// ```
+    /// use arrayvec::ArrayVec;
+    ///
+    /// let mut array = ArrayVec::<[_; 1]>::new();
+    /// assert!(!array.is_full());
+    /// array.push(1);
+    /// assert!(array.is_full());
+    /// ```
+    pub fn is_full(&self) -> bool { self.len() == self.capacity() }
+
     /// Push `element` to the end of the vector.
     ///
     /// Return `None` if the push succeeds, or and return `Some(` *element* `)`
